package com.pgpool.tests;

import com.pgpool.domain.AuthData;

import java.sql.*;
import java.util.HashSet;
import java.util.Set;


public class ShowSqlIssue extends PgpoolTest {
	private static final String SERVER_ADDR_SQL = "select inet_server_addr()";

	@Override
	public void runTest(AuthData authData) throws Exception {

		String url = String.format("jdbc:postgresql://%s:%d/%s?loglevel=2", authData.getPgpoolHostname(), authData.getPgpoolPort(), authData.getDatabaseName());
		try (Connection conn = DriverManager.getConnection(url, authData.getDatabaseLogin(), authData.getDatabasePasswd());
		     Statement stmt = conn.createStatement()) {

			Set<String> serverNames = new HashSet<>();

			System.out.format("Start transaction; execute requests '%s'\n", SERVER_ADDR_SQL);
			conn.setAutoCommit(false);
			for (int i = 0; i < 10; i++) {
				ResultSet rs = stmt.executeQuery(SERVER_ADDR_SQL);
				rs.next();
				String serverName = rs.getString(1);
				serverNames.add(serverName);
				System.out.println("processing server:" + serverName);
			}
			System.out.println("exec 'SHOW TRANSACTION ISOLATION LEVEL'");
			stmt.executeQuery("SHOW TRANSACTION ISOLATION LEVEL").close();

			for (int i = 0; i < 10; i++) {
				ResultSet rs = stmt.executeQuery(SERVER_ADDR_SQL);
				rs.next();
				String serverName = rs.getString(1);
				serverNames.add(serverName);
				System.out.println("processing server:" + serverName);
			}
			System.out.println("Commit transaction");
			conn.commit();

			if (serverNames.size() > 1)
				exitFromFailedTest("Number of servers used to process select is " + serverNames.size() + ", but should be 1");


		} catch (SQLException ex) {
			ex.printStackTrace();
			throw ex;
		}
	}
}